<?php
if ( !defined('ABSPATH')) exit;

if ( ! function_exists( 'eskimo_theme_setup' ) ) {
    function eskimo_theme_setup() {
        
        /* Translations */
        load_theme_textdomain( 'eskimo', get_template_directory() .'/languages' );
        $eskimo_locale = get_locale();
        $eskimo_locale_file = get_template_directory() ."/languages/$eskimo_locale.php";
        if ( is_readable($eskimo_locale_file) ) {
	       require_once($eskimo_locale_file);
        }
        
        /* Add theme support */
        add_theme_support( 'automatic-feed-links' );
        add_theme_support( 'post-thumbnails' );
        add_theme_support( 'title-tag' );
        add_theme_support( 'woocommerce' );
        
        /* Logo */
        $eskimo_logo = array(
            'height'      => 100,
            'width'       => 300,
            'flex-height' => true,
            'flex-width'  => true
        );
        add_theme_support( 'custom-logo', $eskimo_logo );
        
        /* Add tinymce editor style */
        add_editor_style();
        
        /* Register Menus */
        register_nav_menus(
            array(
                'eskimo-main-menu' => esc_html__( 'Main Menu', 'eskimo' )
            )
        );
        
    }
}
add_action( 'after_setup_theme', 'eskimo_theme_setup' );

/*---------------------------------------------------
Content Width
----------------------------------------------------*/
if ( ! isset( $content_width ) ) {
    $content_width = 1200;
}

/*---------------------------------------------------
Change logo link class
----------------------------------------------------*/
function eskimo_change_logo_class( $html ) {
    $html = str_replace( 'custom-logo-link', 'eskimo-logo-link', $html );
    $html = str_replace( 'custom-logo', 'eskimo-logo', $html );
    return $html;
}

add_filter( 'get_custom_logo', 'eskimo_change_logo_class' );


/*---------------------------------------------------
Default SiteOrigin Page Builder Settings
----------------------------------------------------*/
function eskimo_default_page_builder_settings( $settings ) {
    $settings['display-teaser'] = false;
    $settings['recommended-widgets'] = false;
    $settings['post-types'] = array('page');
    $settings['title-html'] = '<h5 class="eskimo-title-with-border"><span>{{title}}</span></h5>';
    $settings['margin-bottom'] = 60;
    $settings['margin-sides'] = 60;
    $settings['tablet-width'] = 991;
    $settings['mobile-width'] = 991;
    $settings['full-width-container'] = '#eskimo-main-container';
    return $settings;
}

add_filter( 'siteorigin_panels_settings_defaults', 'eskimo_default_page_builder_settings' );

/*---------------------------------------------------
Add a body class
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_body_classes' ) ) {
function eskimo_body_classes( $classes ) {
    $classes[] = 'eskimo';    
    return $classes;    
}
}
add_filter( 'body_class','eskimo_body_classes' );

/*---------------------------------------------------
Add a pingback url auto-discovery header for single posts, pages, or attachments.
----------------------------------------------------*/

function eskimo_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'eskimo_pingback_header' );

/*---------------------------------------------------
Custom Thumbnail Sizes
----------------------------------------------------*/

add_image_size( 'eskimo-thumbnail', 900, 600, true);
add_filter('image_size_names_choose', 'eskimo_image_sizes');

function eskimo_image_sizes($eskimosizes) {
    $eskimoaddsizes = array(
        "eskimo-thumbnail" => esc_html__( 'Eskimo Thumbnail', 'eskimo')
    );
    $eskimonewsizes = array_merge($eskimosizes, $eskimoaddsizes);
    return $eskimonewsizes;
}

/*---------------------------------------------------
Wrap category widget post count in a span
----------------------------------------------------*/
if ( ! function_exists( 'eskimo_cat_count_span' ) ) {
function eskimo_cat_count_span($links) {
  $links = str_replace('</a> (', '</a> <span class="badge badge-pill badge-default">', $links);
  $links = str_replace(')', '</span>', $links);
  return $links;
}
}
add_filter('wp_list_categories', 'eskimo_cat_count_span');


/*---------------------------------------------------
Add class to next/previous post links
----------------------------------------------------*/
function eskimo_posts_link_attributes($output) {
    $class = 'class="eskimo-post-nav"';
    return str_replace('<a href=', '<a '.$class.' href=', $output);
}

add_filter('next_post_link', 'eskimo_posts_link_attributes');
add_filter('previous_post_link', 'eskimo_posts_link_attributes');

/*---------------------------------------------------
Create a wrapper and add provider name to the class
----------------------------------------------------*/
if ( ! function_exists( 'eskimo_oembed_wrapper' ) ) {
function eskimo_oembed_wrapper($return, $data, $url) {
    
    /* HTML5 Validation */
    $return = str_replace( array('frameborder="0"', 'webkitallowfullscreen', 'mozallowfullscreen'),'', $return );
    $return = preg_replace('/(<[^>]+) allow=".*?"/i', '$1', $return);
    /* HTML5 Validation END */
    
    $provider = '';
    if(isset($data->provider_name)) {
        $provider = esc_attr($data->provider_name);
    }
    if($provider) {
        return "<div class='eskimo-iframe-outer'><div class='eskimo-iframe $provider'>{$return}</div></div>";
    } else {
        return "<div class='eskimo-iframe-outer'><div class='eskimo-iframe'>{$return}</div></div>";
    }
}
}
add_filter('oembed_dataparse','eskimo_oembed_wrapper',10,3);

/*---------------------------------------------------
Stylesheets
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_theme_styles' ) ) {
function eskimo_theme_styles()  
{   
    $eskimo_disable_external_script = get_theme_mod('eskimo_disable_external_script');
    
    // Default Font
    if (!$eskimo_disable_external_script) {
        wp_enqueue_style('eskimo-font', 'https://fonts.googleapis.com/css?family=Merriweather+Sans:400,700|Merriweather:400,400i,700,700i&subset=latin-ext', false, '');
    }
    
    // Plugins
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/css/fontawesome.css', false, '1.0.0');
    wp_enqueue_style('slick', get_template_directory_uri() . '/css/slick.css', false, '1.8.0');
    
    // Main Styles
    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', false, '4.1.0');
    if (is_rtl()) {
        wp_enqueue_style('bootstrap-rtl', get_template_directory_uri() . '/css/bootstrap-rtl.css', array( 'bootstrap' ), '4.1.0');
    }
    wp_enqueue_style('eskimo-style', get_stylesheet_uri());
    
    // Theme Settings
    $eskimo_default_font_size = get_theme_mod('eskimo_default_font_size', 16);
    $eskimo_link_color = get_theme_mod('eskimo_link_color', '#51cbce');
    $eskimo_link_hover_color = get_theme_mod('eskimo_link_hover_color', '#2ba9cd');
    $eskimo_dark_link_color = get_theme_mod('eskimo_dark_link_color', '#333333');
    $eskimo_dark_link_hover_color = get_theme_mod('eskimo_dark_link_hover_color', '#222222');
    $eskimo_skin_color = get_theme_mod('eskimo_skin_color', '#51cbce');
    $eskimo_second_skin_color = get_theme_mod('eskimo_second_skin_color', '#34b5b8');
    $eskimo_menu_bg = get_theme_mod('eskimo_menu_bg', '');
    $eskimo_menu_link_color = get_theme_mod('eskimo_menu_link_color', '#333333');
    $eskimo_menu_link_hover_color = get_theme_mod('eskimo_menu_link_hover_color', '#51cbce');
    $eskimo_menu_icon_color = get_theme_mod('eskimo_menu_icon_color', '#dddddd');
    $eskimo_main_bg = get_theme_mod('eskimo_main_bg', '');
    $eskimo_card_bg_color = get_theme_mod('eskimo_card_bg_color', '#ffffff');
    $eskimo_panel_bg_color = get_theme_mod('eskimo_panel_bg_color', '#ffffff');
    $eskimo_footer_bg = get_theme_mod('eskimo_footer_bg', '');  
    $eskimo_button_text_color = get_theme_mod('eskimo_button_text_color', '#ffffff');
    $eskimo_button_bg_color = get_theme_mod('eskimo_button_bg_color', '#333333');
    $eskimo_button_hover_bg_color = get_theme_mod('eskimo_button_hover_bg_color', '#222222');
    $eskimo_overlay_color = get_theme_mod('eskimo_overlay_color', 'rgba(255, 255, 255, 0.9)');   
    $eskimo_social_icon_color = get_theme_mod('eskimo_social_icon_color', '#ffffff');
    $eskimo_social_icon_bg = get_theme_mod('eskimo_social_icon_bg', '#333333');   
    $eskimo_page_title_bg = get_theme_mod('eskimo_page_title_bg', '#333333');
    $eskimo_page_title_color = get_theme_mod('eskimo_page_title_color', '#ffffff');
    $eskimo_post_nav_bg = get_theme_mod('eskimo_post_nav_bg', '#333333');
    $eskimo_post_nav_color = get_theme_mod('eskimo_post_nav_color', '#ffffff');
    $eskimo_tag_bg = get_theme_mod('eskimo_tag_bg_color', '#333333');
    
    $eskimo_inline_style = '';
    
    if ( is_admin_bar_showing() ) {
        $eskimo_inline_style .= '@media only screen and (min-width: 1200px) {#eskimo-sidebar {padding-top:32px!important;}}';
        $eskimo_inline_style .= 'progress,.progress-container {top:32px;}@media screen and (max-width: 782px){progress,.progress-container {top:46px;}}@media screen and (max-width: 600px){progress,.progress-container {top:0;}}';
        $eskimo_inline_style .= '@media only screen and (min-width: 1400px) {.eskimo-top-icons {top:32px;}}';
    }
    
    if ((!empty($eskimo_default_font_size) && ($eskimo_default_font_size != 16))) {
        $eskimo_inline_style .= 'html { font-size:' . esc_attr($eskimo_default_font_size) . 'px }@media only screen and (max-width: 1199px) { html {font-size:' . esc_attr($eskimo_default_font_size - 1) . 'px}}@media only screen and (max-width: 575px) { html {font-size:' . esc_attr($eskimo_default_font_size - 2) . 'px} }';
    }
    
    if ((!empty($eskimo_button_text_color) && ($eskimo_button_text_color != '#ffffff'))) {
        $eskimo_inline_style .= '.btn-default,input[type="submit"]:not(.btn):not(.slick-arrow),input[type="button"]:not(.btn):not(.slick-arrow),.button,.eskimo-top-icons li,#eskimo-gototop,.pagination > .page-item > a:hover,.pagination > .page-item > a:focus,.pagination > .page-item > a:active,.pagination > .page-item.active .page-link,.eskimo-post-nav-table > .eskimo-post-nav,.featherlight-close-icon,.featherlight-next,.featherlight-previous,#envirabox-close:after,#envirabox-left-ico:after,#envirabox-right-ico:after,span.eskimo-post-price,.eskimo-carousel-view-more a,.eskimo-carousel-view-more a:hover,.eskimo-slider .slick-prev,.eskimo-slider .slick-next,#eskimo-gototop {color:' . $eskimo_button_text_color . '}';
    }
    
    if ((!empty($eskimo_button_bg_color) && ($eskimo_button_bg_color != '#333333'))) {
        $eskimo_inline_style .= '.btn-default,input[type="submit"]:not(.btn):not(.slick-arrow),input[type="button"]:not(.btn):not(.slick-arrow),.button,.eskimo-top-icons,.eskimo-post-nav-table > .eskimo-post-nav,.featherlight-close-icon,.featherlight-next,.featherlight-previous,#envirabox-close:after,#envirabox-left-ico:after,#envirabox-right-ico:after,body.eskimo #envirabox-title-float-main,span.eskimo-post-price,.eskimo-carousel-view-more,.eskimo-carousel-view-more a,.eskimo-carousel .slick-prev,.eskimo-carousel .slick-next,.eskimo-slider .slick-prev,.eskimo-slider .slick-next,#eskimo-gototop {background-color:' . $eskimo_button_bg_color . ';border-color:' . $eskimo_button_bg_color . ';}';
        $eskimo_inline_style .= '.pagination > .page-item > .dots,.pagination > .page-item > .page-link,.pagination > .page-item > span {border-color:' . $eskimo_button_bg_color . ';color:' . $eskimo_button_bg_color . ';}';
        $eskimo_inline_style .= '.pagination > .page-item > a:hover,.pagination > .page-item > a:focus,.pagination > .page-item > a:active,.pagination > .page-item.active .page-link {border-color:' . $eskimo_button_bg_color . ';background-color:' . $eskimo_button_bg_color . ';}';
    }
    
    if ((!empty($eskimo_button_hover_bg_color) && ($eskimo_button_hover_bg_color != '#222222'))) {
        $eskimo_inline_style .= '.btn-default:hover,.btn-default:focus,.btn-default:active,.btn-default.active,.show > .btn-default.dropdown-toggle,input[type="submit"]:not(.btn):hover,input[type="button"]:not(.btn):hover,.button:hover,.eskimo-post-nav-table > .eskimo-post-nav:hover,.featherlight-next:hover,.featherlight-previous:hover,.featherlight-close-icon:hover,.eskimo-carousel-view-more a:hover,.eskimo-carousel .slick-prev:hover,.eskimo-carousel .slick-next:hover,.eskimo-slider .slick-prev:hover,.eskimo-slider .slick-next:hover,#eskimo-gototop:hover {background-color:' . $eskimo_button_hover_bg_color . ';border-color:' . $eskimo_button_hover_bg_color . ';}';
    }
    
    if (!empty($eskimo_menu_bg)) {
        $eskimo_inline_style .= '#eskimo-sidebar {';
        foreach ( (array) $eskimo_menu_bg as $attr => $value ) {
            if ( ! empty( $value ) ) {
                if ($attr == 'background-image') {
                    $eskimo_inline_style .= $attr  . ':url(' . $value . ');';
                } else {
                    $eskimo_inline_style .= $attr  . ':' . $value . ';';
                }
            }
        }
        $eskimo_inline_style .= '}';
    }
    
    if ((!empty($eskimo_menu_icon_color) && ($eskimo_menu_icon_color != '#dddddd'))) {
        $eskimo_inline_style .= '.eskimo-menu-ul > li > a:after,.eskimo-menu-ul > li > a:before,.eskimo-menu-ul > li > ul > li a:before {background:' . $eskimo_menu_icon_color . '}';
    }
    
    if ((!empty($eskimo_menu_link_color) && ($eskimo_menu_link_color != '#333333'))) {
        $eskimo_inline_style .= '.eskimo-menu-ul li a {color:' . $eskimo_menu_link_color . '}';
    }
    
    if ((!empty($eskimo_menu_link_hover_color) && ($eskimo_menu_link_hover_color != '#51cbce'))) {
        $eskimo_inline_style .= '.eskimo-menu-ul li a:hover,.eskimo-menu-ul li a.eskimo-menu-up {color:' . $eskimo_menu_link_hover_color . '}';
        $eskimo_inline_style .= '.eskimo-menu-ul > li > a:hover:before,.eskimo-menu-ul > li > a:hover:after,.eskimo-menu-ul > li > a.eskimo-menu-up:after,.eskimo-menu-ul > li > a.eskimo-menu-up:before,.eskimo-menu-ul > li > ul > li a:hover:before {background:' . $eskimo_menu_link_hover_color . ';}';
    }
    
    if ((!empty($eskimo_social_icon_color) && ($eskimo_social_icon_color != '#ffffff'))) {
        $eskimo_inline_style .= '.eskimo-social-icons li a {color:' . $eskimo_social_icon_color . '}';
    }
    
    if ((!empty($eskimo_social_icon_bg) && ($eskimo_social_icon_bg != '#51cbce'))) {
        $eskimo_inline_style .= '.eskimo-social-icons {background:' . $eskimo_social_icon_bg . '}';
    }

    if (!empty($eskimo_main_bg)) {
        $eskimo_inline_style .= '#eskimo-site-wrapper {';
        foreach ( (array) $eskimo_main_bg as $attr => $value ) {
            if ( ! empty( $value ) ) {
                if ($attr == 'background-image') {
                    $eskimo_inline_style .= $attr  . ':url(' . $value . ');';
                } else {
                    $eskimo_inline_style .= $attr  . ':' . $value . ';';
                }
            }
        }
        $eskimo_inline_style .= '}';
    }
    
    if (!empty($eskimo_footer_bg)) {
        $eskimo_inline_style .= '#eskimo-footer {';
        foreach ( (array) $eskimo_footer_bg as $attr => $value ) {
            if ( ! empty( $value ) ) {
                if ($attr == 'background-image') {
                    $eskimo_inline_style .= $attr  . ':url(' . $value . ');';
                } else {
                    $eskimo_inline_style .= $attr  . ':' . $value . ';';
                }
            }
        }
        $eskimo_inline_style .= '}';
    }
    
    if ((!empty($eskimo_page_title_bg) && ($eskimo_page_title_bg != '#333333'))) {
        $eskimo_inline_style .= '.eskimo-page-title {background:' . $eskimo_page_title_bg . '}';
    }
    
    if ((!empty($eskimo_page_title_color) && ($eskimo_page_title_color != '#ffffff'))) {
        $eskimo_inline_style .= '.eskimo-page-title h1,.eskimo-page-title-meta a,.eskimo-page-title-meta,.eskimo-page-subtitle {color:' . $eskimo_page_title_color . '}';
    }
    
    if ((!empty($eskimo_post_nav_bg) && ($eskimo_post_nav_bg != '#333333'))) {
        $eskimo_inline_style .= '.eskimo-post-nav-wrapper {background:' . $eskimo_post_nav_bg . '}';
    }
    
    if ((!empty($eskimo_post_nav_color) && ($eskimo_post_nav_color != '#ffffff'))) {
        $eskimo_inline_style .= '.eskimo-post-nav-link a {color:' . $eskimo_post_nav_color . '}';
    }
    
    if ((!empty($eskimo_card_bg_color) && ($eskimo_card_bg_color != '#ffffff'))) {
        $eskimo_inline_style .= '.card,.mp-accordion,.tab-content,.nav-tabs .nav-link.active,.eskimo-slider-desc-inner,.eskimo-slider-desc-inner:before {background-color:' . $eskimo_card_bg_color . '}';
    }
    
    if ((!empty($eskimo_panel_bg_color) && ($eskimo_panel_bg_color != '#ffffff'))) {
        $eskimo_inline_style .= '.eskimo-panel {background-color:' . $eskimo_panel_bg_color . '}';
    }

    if ((!empty($eskimo_link_color) && ($eskimo_link_color != '#51cbce'))) {
        $eskimo_inline_style .= 'a,.eskimo-post-list a:hover {color:' . $eskimo_link_color . '}';
    }
    
    if ((!empty($eskimo_link_hover_color) && ($eskimo_link_hover_color != '#2ba9cd'))) {
        $eskimo_inline_style .= 'a:hover {color:' . $eskimo_link_hover_color . '}';
    }
    
    if ((!empty($eskimo_dark_link_color) && ($eskimo_dark_link_color != '#333333'))) {
        $eskimo_inline_style .= '.card-title a,#eskimo-sidebar .eskimo-logo-link,.nav-tabs .nav-link,.eskimo-post-nav-link a {color:' . $eskimo_dark_link_color . '}';
    }
    
    if ((!empty($eskimo_dark_link_hover_color) && ($eskimo_dark_link_hover_color != '#222222'))) {
        $eskimo_inline_style .= '.card-title a:hover,#eskimo-sidebar .eskimo-logo-link:hover,.nav-tabs .nav-link:hover,.nav-tabs .nav-link.active,.eskimo-post-nav-link a:hover,.mp-accordion-title.collapsed:hover {color:' . $eskimo_dark_link_hover_color . '}';
    } 
    
    if ((!empty($eskimo_tag_bg) && ($eskimo_tag_bg != '#333333'))) {
        $eskimo_inline_style .= '.badge-default {background-color:' . $eskimo_tag_bg . '}';
    }

    if ((!empty($eskimo_skin_color) && ($eskimo_skin_color != '#51cbce'))) {
        $eskimo_inline_style .= 'blockquote {border-left: 4px solid ' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.eskimo-title-with-border span:after {background:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= 'progress,.text-primary,.text-primary:hover,.btn-primary.btn-link,.card .card-footer a:hover,.card-horizontal-meta a:hover,.eskimo-widget a:not(.btn):hover,.card-category,.widget_recent_entries ul li a:hover,.widget_categories ul li a:hover,.widget_recent_comments ul li a:hover,.widget_pages ul li a:hover,.widget_meta ul li a:hover,.widget_archive ul li a:hover,.widget_recent-posts ul li a:hover,.widget_rss ul li a:hover,#recentcomments a:hover,.tagcloud a:hover,a[class^="tag"]:hover {color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= 'progress::-webkit-progress-value {background-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= 'progress::-moz-progress-bar {background-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.eskimo-progress-bar {background-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.eskimo-progress-bar {background-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.btn-primary,.btn-outline-primary:hover,.btn-outline-primary:focus,.btn-outline-primary:active,.btn-outline-primary.active,.open > .btn-outline-primary.dropdown-toggle {background-color:' . $eskimo_skin_color . ';border-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.eskimo-progress-bar,.progress-bar,.progress-bar-primary,.badge-primary,.eskimo-top-icons li a span {background-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.btn-outline-primary {color:' . $eskimo_skin_color . ';border-color:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.eskimo-page-title span:after {background:' . $eskimo_skin_color . ';}';
        $eskimo_inline_style .= '.eskimo-page-title-meta a:hover,.eskimo-post-nav-link a:hover {color:' . $eskimo_skin_color . ';}';
    }
    
    if ((!empty($eskimo_second_skin_color) && ($eskimo_second_skin_color != '#34b5b8'))) {
        $eskimo_inline_style .= '.btn-primary:hover,.btn-primary:focus,.btn-primary:active,.btn-primary.active,.show > .btn-primary.dropdown-toggle {background-color:' . $eskimo_second_skin_color . ';border-color:' . $eskimo_second_skin_color . ';}';
        $eskimo_inline_style .= '.btn-primary.btn-link:hover,.btn-primary.btn-link:focus,.btn-primary.btn-link:active,.btn-primary.btn-link.active,.open > .btn-primary.btn-link.dropdown-toggle {color:' . $eskimo_second_skin_color . ';}';
    }
    
    if ((!empty($eskimo_overlay_color) && ($eskimo_overlay_color != 'rgba(250, 250, 250, 0.9)'))) {
        $eskimo_inline_style .= '#eskimo-overlay,#eskimo-fullscreen-search,#envirabox-overlay {background:' . $eskimo_overlay_color . ' !important}';
    }
    
    wp_add_inline_style( 'eskimo-style', $eskimo_inline_style );
}
}
add_action('wp_enqueue_scripts', 'eskimo_theme_styles');

/*---------------------------------------------------
javascript files
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_script_register' ) ) {
function eskimo_script_register() {
    
    $eskimo_reading_position = get_theme_mod( 'eskimo_reading_position' );
    
    // Bootstrap
    wp_enqueue_script('eskimo-bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), '4.1.0', true );
    
    // Responsive Grid
    wp_enqueue_script('salvattore', get_template_directory_uri() . '/js/salvattore.min.js', array( 'jquery' ), '1.0.9', true );
    
    // Reading Position Indicator
    if ($eskimo_reading_position) {
        wp_enqueue_script('eskimo-reading-position', get_template_directory_uri() . '/js/reading-position-indicator.js', array( 'jquery' ), '1.0.0', true );
    }
    
    // Slick carousel
    wp_enqueue_script('slick', get_template_directory_uri() . '/js/slick/slick.min.js', array( 'jquery' ), '1.8.0', true );
    
    // Off-Canvas Panel
    if (!is_rtl()) {
        wp_enqueue_script('eskimo-panel', get_template_directory_uri() . '/js/panel.js', array( 'jquery' ), '1.0.0', true );
    } else {
        wp_enqueue_script('eskimo-panel-rtl', get_template_directory_uri() . '/js/panel-rtl.js', array( 'jquery' ), '1.0.0', true );
    }
    
    // Comments
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( "comment-reply" );
    }
    
    // Custom
    wp_enqueue_script('eskimo-custom', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), '1.0.0', true );
    
    $eskimo_language = 'default';
    if (is_rtl()) {
        $eskimo_language = 'rtl';
    }
    
    $eskimo_script_param = array(
        "eskimo_language" => $eskimo_language
    );
    wp_localize_script('eskimo-custom', 'eskimo_script_vars', $eskimo_script_param);
}
}
add_action( 'wp_enqueue_scripts', 'eskimo_script_register' );

/*---------------------------------------------------
Dashboard scripts
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_theme_admin_scripts' ) ) {
function eskimo_theme_admin_scripts(){
    wp_enqueue_style('eskimo-theme-admin-style', get_template_directory_uri() . '/includes/css/admin-general.css', false, '1.0');
}
}
add_action( 'admin_enqueue_scripts', 'eskimo_theme_admin_scripts', 99 );

/*---------------------------------------------------
Register Sidebars
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_sidebars_widgets_init' ) ) {
function eskimo_sidebars_widgets_init() {
    register_sidebar( array(
        'name' => esc_html__( 'Main Sidebar', 'eskimo'),
        'id' => 'eskimo_main_sidebar',
        'description' => esc_html__( 'Sliding Sidebar', 'eskimo' ),
        'before_widget' => '<div id="%1$s" class="%2$s eskimo-widget">',
        'after_widget' => "</div>",
        'before_title' => '<h5 class="eskimo-title-with-border"><span>',
        'after_title' => '</span></h5>',
    ));
    register_sidebar( array(
        'name' => esc_html__( 'Woocommerce Sidebar', 'eskimo'),
        'id' => 'eskimo_woo_sidebar',
        'description' => esc_html__( 'Sliding Sidebar', 'eskimo' ),
        'before_widget' => '<div id="%1$s" class="%2$s eskimo-widget">',
        'after_widget' => "</div>",
        'before_title' => '<h5 class="eskimo-title-with-border"><span>',
        'after_title' => '</span></h5>',
    ));
    register_sidebar( array(
        'name' => esc_html__( 'Footer', 'eskimo'),
        'id' => 'eskimo_footer_widgets',
        'description' => esc_html__( 'You can use SiteOrigin Layout Builder Widget to create multiple column in the footer.', 'eskimo' ),
        'before_widget' => '<div id="%1$s" class="%2$s eskimo-widget">',
        'after_widget' => "</div>",
        'before_title' => '<h5 class="eskimo-title-with-border"><span>',
        'after_title' => '</span></h5>',
    ));
}
}
add_action( 'widgets_init', 'eskimo_sidebars_widgets_init' );

/*---------------------------------------------------
Custom excerpt dots
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_excerpt_read_more' ) ) {
function eskimo_excerpt_read_more( $more ) {
	return '...';
}
}
add_filter('excerpt_more', 'eskimo_excerpt_read_more');

/*---------------------------------------------------
Custom tag cloud
----------------------------------------------------*/
if ( ! function_exists( 'eskimo_wp_generate_tag_cloud' ) ) {
function eskimo_wp_generate_tag_cloud($content, $tags, $args)
{ 
    if ( ! is_admin() ) {
        $count=0;
        $output=preg_replace_callback('(</a\s*>)', function($match) use ($tags, &$count) {
            return "<span class=\"eskimo-tag-count\">".$tags[$count++]->count."</span></a>";  
        }, $content);
    } else {
        $output = $content;
    }
  return $output;    
}
}
add_filter('wp_generate_tag_cloud','eskimo_wp_generate_tag_cloud', 10, 3);

if ( ! function_exists( 'eskimo_tag_cloud_args' ) ) {
    function eskimo_tag_cloud_args($args) {
        $eskimo_args = array('smallest' => 14, 'largest' => 14, 'orderby' => 'count','unit' => 'px','order' => 'DESC');
        $args = wp_parse_args( $args, $eskimo_args );
        return $args;
    }
}
add_filter('widget_tag_cloud_args','eskimo_tag_cloud_args');

/*---------------------------------------------------
Custom comments
----------------------------------------------------*/
if ( ! function_exists( 'eskimo_comment' ) ) {
function eskimo_comment($comment, $args, $depth) {
$GLOBALS['comment'] = $comment; ?>
<div <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">      
    <div id="comment-<?php comment_ID(); ?>" class="eskimo_comments"> 
        <?php if ($comment->comment_approved == '0') : ?>
        <em><?php echo esc_html('Your comment is awaiting moderation.', 'eskimo'); ?></em>
        <br />
        <?php endif; ?> 
        <div class="eskimo_comment">
            <div class="eskimo_comment_inner">
                <?php $eskimo_avatar = get_avatar( $comment, 60 ); ?>
                <?php if (!empty($eskimo_avatar)) { ?>
                <div class="eskimo_comment_left">
                    <?php echo get_avatar( $comment, 60 ); ?> 
                </div>
                <?php } ?>
                <div class="eskimo_comment_right">
                    <div class="eskimo_comment_right_inner <?php if (empty($eskimo_avatar)) { ?>eskimo_no_avatar<?php } ?>">
                    <cite class="eskimo_fn"><?php printf(esc_attr('%s'), get_comment_author_link()) ?></cite>
                    <div class="eskimo_comment_links">
                        <a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><i class="fa fa-clock-o"></i> <?php printf(esc_html__('%1$s at %2$s', 'eskimo'), get_comment_date(),  get_comment_time()) ?></a> - <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?><?php edit_comment_link(esc_html__('(Edit)', 'eskimo'),'  ','') ?>
                    </div>    
                    <div class="eskimo_comment_text">
                        <?php comment_text(); ?>
                    </div> 
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php
}          
}

/* ---------------------------------------------------------
Calculate Reading Time
----------------------------------------------------------- */
function eskimo_reading_time($post_id) {
    $content = get_post_field( 'post_content', $post_id );
    $word_count = str_word_count( strip_tags( $content ) );
    $readingtime = ceil($word_count / 200);
    $timer = ' ' . esc_html__('min read', 'eskimo');
    $totalreadingtime = $readingtime . $timer;
    return $totalreadingtime;
}

/* ---------------------------------------------------------
Add a class to Mailchimp form
----------------------------------------------------------- */
add_filter( 'mc4wp_form_css_classes', function( $classes ) { 
	$classes[] = 'eskimo-mailchimp';
	return $classes;
});

/* ---------------------------------------------------------
TGM Activation Class
----------------------------------------------------------- */

require_once(get_template_directory() . '/includes/class-tgm-plugin-activation.php');

add_action( 'tgmpa_register', 'eskimo_register_required_plugins' );

function eskimo_register_required_plugins() {
	$eskimo_plugins = array(
		array(
			'name'     				=> esc_html__( 'Eskimo Features', 'eskimo'),
			'slug'     				=> 'eskimo-features',
			'source'   				=> get_template_directory_uri() . '/plugins/eskimo-features.zip',
			'required' 				=> true,
            'version' 				=> '1.8.2',
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),
        array(
			'name'     				=> esc_html__( 'Kirki', 'eskimo'),
			'slug'     				=> 'kirki',
			'required' 				=> true,
		),
        array(
			'name'     				=> esc_html__( 'Siteorigin Panels', 'eskimo'),
			'slug'     				=> 'siteorigin-panels',
			'required' 				=> true,
		),
        array(
			'name'     				=> esc_html__( 'SiteOrigin Widgets Bundle', 'eskimo'),
			'slug'     				=> 'so-widgets-bundle',
			'required' 				=> true,
		),
        array(
			'name'     				=> esc_html__( 'CMB2', 'eskimo'),
			'slug'     				=> 'cmb2',
			'required' 				=> true,
		),
        array(
			'name'     				=> esc_html__( 'Woocommerce', 'eskimo'),
			'slug'     				=> 'woocommerce',
			'required' 				=> false,
		),
        array(
			'name'     				=> esc_html__( 'Envira Gallery', 'eskimo'),
			'slug'     				=> 'envira-gallery-lite',
			'required' 				=> false,
		),
        array(
			'name'     				=> esc_html__( 'Contact Form 7', 'eskimo'),
			'slug'     				=> 'contact-form-7',
			'required' 				=> false,
		),
        array(
			'name'     				=> esc_html__( 'One Click Demo Import', 'eskimo'),
			'slug'     				=> 'one-click-demo-import',
			'required' 				=> false,
		)
	);

	$eskimo_config = array(
        'id'           => 'eskimo',
		'default_path' => '',
		'menu'         => 'tgmpa-install-plugins',
		'has_notices'  => true,
		'dismissable'  => true,
		'dismiss_msg'  => '',
		'is_automatic' => false,
		'message'      => '',
	);

	tgmpa( $eskimo_plugins, $eskimo_config );

}
?>