<?php
/*---------------------------------------------------
Remove default layout
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_woo_dequeue_styles' ) ) {
    function eskimo_woo_dequeue_styles( $enqueue_styles ) {
        unset( $enqueue_styles['woocommerce-layout'] );
        return $enqueue_styles;
    }
}
add_filter( 'woocommerce_enqueue_styles', 'eskimo_woo_dequeue_styles' );

/*---------------------------------------------------
Ajax show cart total
----------------------------------------------------*/
if ( ! function_exists( 'eskimo_cart_count_ajax' ) ) { 
function eskimo_cart_count_ajax( $fragments ) {    
    $fragments['span.icon-count'] = '<span class="icon-count">' . WC()->cart->get_cart_contents_count() . '</span>';
    return $fragments;   
}
}
add_filter( 'woocommerce_add_to_cart_fragments', 'eskimo_cart_count_ajax', 10, 1 );

/*---------------------------------------------------
Before shop loop item
----------------------------------------------------*/
function eskimo_before_shop_loop_item_title() {
    global $product;
    if ( ! $product->managing_stock() && ! $product->is_in_stock() ) { ?>
       <div class="eskimo-out-of-stock"> <?php esc_html_e('Out of Stock', 'eskimo'); ?> </div>
    <?php
    }
}
add_action( 'woocommerce_before_shop_loop_item_title', 'eskimo_before_shop_loop_item_title', 10 );

/*---------------------------------------------------
Add divider before product button
----------------------------------------------------*/
function eskimo_product_divider_start() { ?>
        </div>
<?php
}
add_action( 'woocommerce_after_shop_loop_item', 'eskimo_product_divider_start', 4 );

function eskimo_product_divider_end() { ?>
        <div class="card-footer product-footer">
<?php
}
add_action( 'woocommerce_after_shop_loop_item', 'eskimo_product_divider_end', 6 );

/*---------------------------------------------------
Change default product thumbnail size
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_product_thumbnail_size' ) ) {
    function eskimo_product_thumbnail_size($size) {	
        $size = esc_html(get_theme_mod('eskimo_product_thumbnail', 'large'));
        return $size;
    }
}

add_filter( 'single_product_archive_thumbnail_size' , 'eskimo_product_thumbnail_size' );
add_filter( 'subcategory_archive_thumbnail_size' , 'eskimo_product_thumbnail_size' );

/*---------------------------------------------------
Custom placeholder
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_custom_woocommerce_placeholder' ) ) {
function eskimo_custom_woocommerce_placeholder( $image_url ) {
    $eskimo_woo_placeholder = esc_html(get_theme_mod('eskimo_woo_placeholder'));
    if (!empty($eskimo_woo_placeholder)) {
        $image_url = esc_url($eskimo_woo_placeholder);
    } else {
        $image_url = get_template_directory_uri() ."/images/woocommerce-placeholder.png";
    }
    return $image_url;
}
}

add_filter( 'woocommerce_placeholder_img_src', 'eskimo_custom_woocommerce_placeholder', 10 );

/*---------------------------------------------------
Product per page
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_loop_shop_per_page' ) ) {
    function eskimo_loop_shop_per_page( $cols ) {
        $cols = esc_html(get_theme_mod('eskimo_shop_at_most', 8));
        return $cols;
    }
}

add_filter( 'loop_shop_per_page', 'eskimo_loop_shop_per_page', 20 );

/*---------------------------------------------------
Related Products
----------------------------------------------------*/

$eskimo_remove_related = esc_html(get_theme_mod('eskimo_remove_related', 1));

if ($eskimo_remove_related == 0) {
    remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
}

function eskimo_related_products_args( $args ) {
    $eskimo_related_at_most = esc_html(get_theme_mod('eskimo_related_at_most', 2));
	$args['posts_per_page'] = $eskimo_related_at_most;
	$args['columns'] = 2;
	return $args;
}

add_filter( 'woocommerce_output_related_products_args', 'eskimo_related_products_args' );

/*---------------------------------------------------
Remove page titles and taxonomy description
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_woo_hide_page_title' ) ) {
    function eskimo_woo_hide_page_title() {	
        return false;	
    }
}

add_filter( 'woocommerce_show_page_title' , 'eskimo_woo_hide_page_title' );
remove_action( 'woocommerce_archive_description' , 'woocommerce_taxonomy_archive_description', 10 );

/*---------------------------------------------------
Custom scripts
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_woo_print_scripts' ) ) {
    function eskimo_woo_print_scripts()
    {      
        if ( is_product() ) {
            wp_enqueue_style('featherlight', get_template_directory_uri() . '/css/featherlight.css', false, '1.5.1');
            wp_enqueue_script('featherlight', get_template_directory_uri() . '/js/featherlight.js', array( 'jquery' ), '1.5.1', true );
            if(!is_rtl()) {
                wp_enqueue_script('eskimo-format-gallery', get_template_directory_uri() . '/js/slick/format-gallery.js', array( 'jquery' ), '1.0', true );
            }
            else {
                wp_enqueue_script('eskimo-format-gallery-rtl', get_template_directory_uri() . '/js/slick/format-gallery-rtl.js', array( 'jquery' ), '1.0', true );
            }
        }
    }
}
add_action('wp_enqueue_scripts', 'eskimo_woo_print_scripts');

/*---------------------------------------------------
Custom styles
----------------------------------------------------*/

if ( ! function_exists( 'eskimo_woo_print_styles' ) ) {
    function eskimo_woo_print_styles()
    {        
        wp_enqueue_style('eskimo-woo', get_template_directory_uri() . '/css/woocommerce.css', false, '1.0');
        
        if (is_rtl()) {
            wp_enqueue_style('eskimo-woo-rtl', get_template_directory_uri() . '/css/woocommerce-rtl.css', false, '1.0');
        }
        
        $eskimo_product_img_size = esc_html(get_theme_mod('eskimo_product_img_size', 50));
        $eskimo_button_text_color = esc_attr(get_theme_mod('eskimo_button_text_color', '#ffffff'));
        $eskimo_button_bg_color = esc_attr(get_theme_mod('eskimo_button_bg_color', '#333333'));
        $eskimo_button_hover_bg_color = esc_attr(get_theme_mod('eskimo_button_hover_bg_color', '#222222'));
        $eskimo_dark_link_color = esc_attr(get_theme_mod('eskimo_dark_link_color', '#333333'));
        $eskimo_dark_link_hover_color = esc_attr(get_theme_mod('eskimo_dark_link_hover_color', '#222222'));
        $eskimo_page_title_color = get_theme_mod('eskimo_page_title_color', '#ffffff');
        $eskimo_skin_color = esc_attr(get_theme_mod('eskimo_skin_color', '#51cbce'));
        
        $eskimo_woo_inline_style = '';
        
        if ($eskimo_product_img_size != 50) {
            $eskimo_woo_inline_style .= '.eskimo-single-product-left {width: ' . $eskimo_product_img_size . '%;}.eskimo-single-product-right {width: ' . (100 - $eskimo_product_img_size) . '%;}';   
        }
        
        if ((!empty($eskimo_button_text_color) && ($eskimo_button_text_color != '#ffffff'))) {
            $eskimo_woo_inline_style .= '.woocommerce #respond input#submit,.woocommerce a.button,.woocommerce button.button,.woocommerce input.button,.woocommerce #respond input#submit.alt,.woocommerce a.button.alt,.woocommerce button.button.alt,.woocommerce input.button.alt,.woocommerce a.added_to_cart,.woocommerce input.button.disabled,.woocommerce input.button.disabled:hover,.woocommerce input.button:disabled,.woocommerce input.button:disabled:hover,.woocommerce input.button:disabled[disabled],.woocommerce input.button:disabled[disabled]:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover,.woocommerce input.button.alt:hover,.eskimo-zoom-icon {color:' . $eskimo_button_text_color . '}';
        }
        
        if ((!empty($eskimo_button_bg_color) && ($eskimo_button_bg_color != '#333333'))) {
            $eskimo_woo_inline_style .= '.woocommerce #respond input#submit,.woocommerce a.button,.woocommerce button.button,.woocommerce input.button,.woocommerce #respond input#submit.alt,.woocommerce a.button.alt,.woocommerce button.button.alt,.woocommerce input.button.alt,.woocommerce a.added_to_cart,.woocommerce input.button.disabled,.woocommerce input.button.disabled:hover,.woocommerce input.button:disabled,.woocommerce input.button:disabled:hover,.woocommerce input.button:disabled[disabled],.woocommerce input.button:disabled[disabled]:hover,.eskimo-zoom-icon,.woocommerce-MyAccount-navigation ul li.is-active {background-color:' . $eskimo_button_bg_color . ';border-color:' . $eskimo_button_bg_color . ';}';
            $eskimo_woo_inline_style .= '.woocommerce nav.woocommerce-pagination ul li a,.woocommerce nav.woocommerce-pagination ul li span {border-color:' . $eskimo_button_bg_color . ';color:' . $eskimo_button_bg_color . ';}';
            $eskimo_woo_inline_style .= '.woocommerce nav.woocommerce-pagination ul li a:focus,.woocommerce nav.woocommerce-pagination ul li a:hover,.woocommerce nav.woocommerce-pagination ul li span.current {border-color:' . $eskimo_button_bg_color . ' !important;background-color:' . $eskimo_button_bg_color . ' !important;}';
            $eskimo_woo_inline_style .= '.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {background:' . $eskimo_button_bg_color . ';}';
        }
        
        if ((!empty($eskimo_button_hover_bg_color) && ($eskimo_button_hover_bg_color != '#222222'))) {
            $eskimo_woo_inline_style .= '.woocommerce #respond input#submit:hover,.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover,.woocommerce input.button.alt:hover {background-color:' . $eskimo_button_hover_bg_color . ';border-color:' . $eskimo_button_hover_bg_color . ';}';
        }
        
        if ((!empty($eskimo_dark_link_color) && ($eskimo_dark_link_color != '#333333'))) {
            $eskimo_woo_inline_style .= '.woocommerce-mini-cart__empty-message,.woocommerce-MyAccount-navigation ul li a,.woocommerce ul.product_list_widget li.empty:before,.woocommerce .widget_shopping_cart .total .woocommerce-Price-amount,.woocommerce.widget_shopping_cart .total .woocommerce-Price-amount,.woocommerce.widget_layered_nav ul li a:hover,.woocommerce.widget_layered_nav ul li:hover:after,.woocommerce div.product p.price,.woocommerce div.product span.price,.woocommerce.card-masonry span.price {color:' . $eskimo_dark_link_color . '}';
        }
    
        if ((!empty($eskimo_dark_link_hover_color) && ($eskimo_dark_link_hover_color != '#222222'))) {
            $eskimo_woo_inline_style .= '.woocommerce-MyAccount-navigation ul li a:hover {color:' . $eskimo_dark_link_hover_color . '}';
        } 
        
        if ((!empty($eskimo_page_title_color) && ($eskimo_page_title_color != '#ffffff'))) {
            $eskimo_woo_inline_style .= '.woocommerce .woocommerce-breadcrumb a,.woocommerce .woocommerce-breadcrumb {color:' . $eskimo_page_title_color . '}';
        }
        
        if ((!empty($eskimo_skin_color) && ($eskimo_skin_color != '#51cbce'))) {
            $eskimo_woo_inline_style .= '.woocommerce-mini-cart__empty-message {border-color:' . $eskimo_skin_color . ';background-color:' . $eskimo_skin_color . ';}';
            $eskimo_woo_inline_style .= '.woocommerce .widget_price_filter .ui-slider .ui-slider-range {background:' . $eskimo_skin_color . ';}';
            $eskimo_woo_inline_style .= '.woocommerce .woocommerce-breadcrumb a:hover {color:' . $eskimo_skin_color . ';}';
        }
        
        wp_add_inline_style( 'eskimo-woo', $eskimo_woo_inline_style );
    }
}
add_action('wp_enqueue_scripts', 'eskimo_woo_print_styles', 99);
?>