<?php
/**
 * Single Product Image
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/product-image.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$eskimo_product_image = esc_attr(get_theme_mod('eskimo_product_image', 'full'));

global $post, $product;
$columns           = apply_filters( 'woocommerce_product_thumbnails_columns', 4 );
$post_thumbnail_id = get_post_thumbnail_id( $post->ID );
$full_size_image   = wp_get_attachment_image_src( $post_thumbnail_id, 'full' );
$image_title       = get_post_field( 'post_excerpt', $post_thumbnail_id );
$placeholder       = has_post_thumbnail() ? 'with-images' : 'without-images';
$wrapper_classes   = apply_filters( 'woocommerce_single_product_image_gallery_classes', array(
	'woocommerce-product-gallery',
	'woocommerce-product-gallery--' . $placeholder,
	'woocommerce-product-gallery--columns-' . absint( $columns ),
	'images',
) );
?>
<div class="eskimo-post-format-gallery eskimo-bg-loader">
    <div id="eskimo-gallery-slider" class="hide-on-load">
        <?php
		$attributes = array(
			'title'                   => $image_title,
			'data-src'                => $full_size_image[0],
			'data-large_image'        => $full_size_image[0],
			'data-large_image_width'  => $full_size_image[1],
			'data-large_image_height' => $full_size_image[2],
		);

		if ( has_post_thumbnail() ) {
            $html  = '<div class="woo-lightbox" data-featherlight="' . esc_url( $full_size_image[0] ) . '" data-thumbnail="' . get_the_post_thumbnail_url( $post->ID, 'shop_thumbnail' ) . '"><div class="eskimo-zoom-icon"><i class="fa fa-expand"></i></div>';
			$html .= '<img src="' . get_the_post_thumbnail_url( $post->ID, $eskimo_product_image, $attributes ) . '" alt="' . get_the_title() . '" />';
			$html .= '</div>';
		} else {
			$html  = '<div class="woocommerce-product-gallery__image--placeholder">';
			$html .= sprintf( '<img src="%s" alt="%s" class="wp-post-image" />', esc_url( wc_placeholder_img_src() ), esc_html__( 'Awaiting product image', 'eskimo' ) );
			$html .= '</div>';
		}

		echo apply_filters( 'woocommerce_single_product_image_thumbnail_html', $html, get_post_thumbnail_id( $post->ID ) );


        $attachment_ids = $product->get_gallery_image_ids();


if ( $attachment_ids && has_post_thumbnail() ) {
	foreach ( $attachment_ids as $attachment_id ) {
		$full_size_image = wp_get_attachment_image_src( $attachment_id, 'full' );
		$thumbnail       = wp_get_attachment_image_src( $attachment_id, 'thumbnail' );
		$image_title     = get_post_field( 'post_excerpt', $attachment_id );

		$attributes = array(
			'title'                   => $image_title,
			'data-src'                => $full_size_image[0],
			'data-large_image'        => $full_size_image[0],
			'data-large_image_width'  => $full_size_image[1],
			'data-large_image_height' => $full_size_image[2],
		);
        if ($full_size_image) {
        $html  = '<div class="woo-lightbox" data-featherlight="' . esc_url( $full_size_image[0] ) . '" data-thumbnail="' . esc_url( $thumbnail[0] ) . '"><div class="eskimo-zoom-icon"><i class="fa fa-expand"></i></div>';
        $html .= '<img src="' . wp_get_attachment_image_url( $attachment_id, $eskimo_product_image, $attributes ) . '" alt="' . get_the_title() . '" />';
 		$html .= '</div>';

		echo apply_filters( 'woocommerce_single_product_image_thumbnail_html', $html, $attachment_id );
        }
        
	}
}
    ?>
    </div>
    <?php if ( $attachment_ids && has_post_thumbnail() ) { ?>
    <div id="eskimo-gallery-dots-container" class="eskimo-post-slider-thumbnails"></div>
    <?php } ?>
    <div class="clearfix"></div>
</div>